@@ -37,7 +37,7 @@ unite.dm <- function(data, ...) {
 #' @rdname tidyr_table_manipulation
 #' @export
 unite.zoomed_dm <- function(data, col, ..., sep = "_", remove = TRUE, na.rm = FALSE) {
-  tbl <- get_zoomed_tbl(data)
+  tbl <- tbl_zoomed(data)
   united_tbl <- unite(tbl, col = !!col, ..., sep = sep, remove = remove, na.rm = na.rm)
 
   # all columns that are not not removed count as "selected"; names of "selected" are identical to "selected"
@@ -46,7 +46,7 @@ unite.zoomed_dm <- function(data, col, ..., sep = "_", remove = TRUE, na.rm = FA
   } else {
     deselected <- eval_select_both(quo(c()), colnames(tbl))
   }
-  selected <- set_names(setdiff(names(get_tracked_cols(data)), deselected$names))
+  selected <- set_names(setdiff(names(col_tracker_zoomed(data)), deselected$names))
   new_tracked_cols_zoom <- new_tracked_cols(data, selected)
 
   replace_zoomed_tbl(data, united_tbl, new_tracked_cols_zoom)
@@ -60,12 +60,12 @@ separate.dm <- function(data, ...) {
 #' @rdname tidyr_table_manipulation
 #' @export
 separate.zoomed_dm <- function(data, col, into, sep = "[^[:alnum:]]+", remove = TRUE, ...) {
-  tbl <- get_zoomed_tbl(data)
+  tbl <- tbl_zoomed(data)
   col <- tidyselect::vars_pull(names(tbl), !!enquo(col))
   separated_tbl <- separate(tbl, col = !!col, into = into, sep = sep, remove = remove, ...)
   # all columns that are not removed count as "selected"; names of "selected" are identical to "selected"
   deselected <- if (remove) col else character()
-  selected <- set_names(setdiff(names(get_tracked_cols(data)), deselected))
+  selected <- set_names(setdiff(names(col_tracker_zoomed(data)), deselected))
   new_tracked_cols_zoom <- new_tracked_cols(data, selected)
   replace_zoomed_tbl(data, separated_tbl, new_tracked_cols_zoom)
 }
