@@ -27,7 +27,7 @@ test_that("cdm_copy_to() behaves correctly", {
   local_options(lifecycle_verbosity = "quiet")
 
   expect_equivalent_dm(
-    cdm_copy_to(sqlite(), dm_for_filter_simple(), unique_table_names = TRUE),
+    cdm_copy_to(sqlite_test_src(), dm_for_filter_simple(), unique_table_names = TRUE),
     dm_for_filter_simple()
   )
 })
@@ -37,8 +37,8 @@ test_that("cdm_disambiguate_cols() works as intended", {
   local_options(lifecycle_verbosity = "quiet")
 
   expect_equivalent_dm(
-    expect_message(cdm_disambiguate_cols(dm_for_disambiguate())),
-    expect_message(dm_disambiguate_cols(dm_for_disambiguate()))
+    expect_message_obj(cdm_disambiguate_cols(dm_for_disambiguate())),
+    expect_message_obj(dm_disambiguate_cols(dm_for_disambiguate()))
   )
 })
 
@@ -94,12 +94,12 @@ test_that("`cdm_flatten_to_tbl()`, `cdm_join_to_tbl()` and `dm_squash_to_tbl()`
   local_options(lifecycle_verbosity = "quiet")
 
   expect_equivalent_tbl(
-    expect_message(cdm_flatten_to_tbl(dm_for_flatten(), fact)),
+    expect_message_obj(cdm_flatten_to_tbl(dm_for_flatten(), fact)),
     result_from_flatten()
   )
 
   expect_equivalent_tbl(
-    expect_message(cdm_join_to_tbl(dm_for_flatten(), fact, dim_3)),
+    expect_message_obj(cdm_join_to_tbl(dm_for_flatten(), fact, dim_3)),
     select(result_from_flatten(), fact:fact.something, dim_3.something)
   )
 })
@@ -113,10 +113,9 @@ test_that("cdm_get_src() works", {
     class = "is_not_dm"
   )
 
-  skip_if_local_src()
   expect_identical(
-    class(cdm_get_src(dm_for_filter_simple())),
-    class(my_test_src())
+    class(cdm_get_src(dm_for_filter_simple_db())),
+    class(my_db_test_src())
   )
 })
 
@@ -261,7 +260,7 @@ test_that("cdm_examine_constraints() works", {
 
   expect_identical(
     cdm_check_constraints(bad_dm()),
-    dm_examine_constraints_impl(bad_dm())
+    dm_examine_constraints_impl(bad_dm(), progress = FALSE)
   )
 })
 
